==> cpg-core-4.4.1-sources.jar: de/fraunhofer/aisec/cpg/graph/statements/expressions/ProblemExpression.kt <==
/*
 * Copyright (c) 2022, Fraunhofer AISEC. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */
package de.fraunhofer.aisec.cpg.graph.statements.expressions

import de.fraunhofer.aisec.cpg.graph.Node
import de.fraunhofer.aisec.cpg.graph.ProblemNode
import org.apache.commons.lang3.builder.ToStringBuilder

/**
 * A node where the statement could not be translated by the graph. We use ProblemExpressions
 * whenever the CPG library requires an [Expression].
 */
class ProblemExpression(
    override var problem: String = "",
    override var type: ProblemNode.ProblemType = ProblemNode.ProblemType.TRANSLATION
) : Expression(), ProblemNode {
    override fun toString(): String {
        return ToStringBuilder(this, Node.TO_STRING_STYLE)
            .appendSuper(super.toString())
            .append("problem", problem)
            .toString()
    }

    override fun equals(o: Any?): Boolean {
        if (this === o) {
            return true
        }
        if (o !is ProblemExpression) {
            return false
        }
        val that = o
        return (super.equals(that) && problem == that.problem)
    }

    override fun hashCode(): Int {
        return super.hashCode()
    }
}

==> cpg-core-8.3.0-sources.jar: de/fraunhofer/aisec/cpg/graph/statements/expressions/ProblemExpression.kt <==
/*
 * Copyright (c) 2022, Fraunhofer AISEC. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */
package de.fraunhofer.aisec.cpg.graph.statements.expressions

import de.fraunhofer.aisec.cpg.graph.ProblemNode
import java.util.Objects
import org.apache.commons.lang3.builder.ToStringBuilder

/**
 * A node where the statement could not be translated by the graph. We use ProblemExpressions
 * whenever the CPG library requires an [Expression].
 */
class ProblemExpression(
    override var problem: String = "",
    override var problemType: ProblemNode.ProblemType = ProblemNode.ProblemType.TRANSLATION
) : Expression(), ProblemNode {
    override fun toString(): String {
        return ToStringBuilder(this, TO_STRING_STYLE)
            .appendSuper(super.toString())
            .append("problem", problem)
            .toString()
    }

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (other !is ProblemExpression) return false
        return super.equals(other) && problem == other.problem
    }

    override fun hashCode() = Objects.hash(super.hashCode(), problem)
}
